@@ -4,85 +4,38 @@
 ## population size in an arbitrary region
 ## 2011-08-18 (fixed expected.n)
 ## 2011-09-26 fixed multi-session bug in region.N
-############################################################################################
-
-predictD <- function (object, region, session) {
-    ## not exported
-    ## groups not thought through yet...
-    ## if (!is.null(group))
-    ##    newdata <- subset (newdata[newdata$g == group,]
-
-    if (is.null(object$model$D)) {    ## object$CL == TRUE
-        temp <- derived(object) ## inefficient as repeats for each sess
-        if (!is.data.frame(temp))
-            temp <- temp[[session]]
-        D <- temp['D', 'estimate']
-        return (D)
-    }
-    else {
-        newdata <- D.designdata (region, object$model$D,
-             group.levels(object$capthist,object$groups),
-             session(object$capthist), sessioncov = object$sessioncov)
-        ## select a single session
-        if ("session" %in% names(newdata)) {
-# following does not work 2011-09-26
-#            newdata <- subset(newdata, subset = (newdata$session == session))
-            newdata <- newdata[newdata$session == session,]
-        }
-        if ("Session" %in% names(newdata)) {
-#            newdata <- subset(newdata, subset = newdata$Session ==
-#               as.numeric(factor(session, levels =  session(object$capthist)))-1)
-            newdata <- newdata[newdata$Session ==
-               (as.numeric(factor(session, levels =  session(object$capthist)))-1),]
-        }
-        class(newdata) <- c('mask', 'data.frame')
-        attr (newdata, 'area') <- attr(region, 'area')
-        indx <- object$parindx$D
-        beta <- object$fit$par[indx]
-        if (object$model$D == ~1) {
-            D <- untransform(beta, object$link$D)
-            return ( rep(D, nrow(region) ))
-        }
-        else {
-            vars <- all.vars(object$model$D)
-            if (any(!(vars %in% names(newdata))))
-                stop ("one or more model covariates not found")
-            newdata <- as.data.frame(newdata)
-            mat <- model.matrix(object$model$D, data=newdata)
-            lpred <- mat %*% beta
-            return ( untransform(lpred, object$link$D) )
-        }
-    }
-}
-
+## 2011-10-19 adjustments for speed, observe se.N
+## 2011-10-19 slowness is due to call of integralprw1 in sumDpdot
+## 2011-10-20 minor editing
+## 2011-10-21 predictD moved to Dsurface.R
 ############################################################################################
 
 region.N <- function (object, region = NULL, spacing = NULL, session = NULL,
     group = NULL, se.N = TRUE, alpha = 0.05, loginterval = TRUE,
-    keep.region = FALSE, nlowerbound = TRUE) {
+    keep.region = FALSE, nlowerbound = TRUE, RN.method = 'poisson') {
 
     ## Notes
     ## se.N = FALSE returns scalar N
 
     ###########################################################
     ## for gradient of E.N wrt density betas
-    betaN <- function (betaD, object, region, session, group) {
-        ## assume region is a mask (no need for spacing)
+    betaEN <- function (betaD, object, regionmask, group, session) {
+        ## regionmask is a mask (no need for spacing)
         ## assume single session
         ## indx identifies beta parameters for density D
         object$fit$par[indx] <- betaD
-        region.N(object, region, spacing = NULL, session = session,
+        region.N(object, regionmask, spacing = NULL, session = session,
             group = group, se.N = FALSE, keep.region = FALSE)
     }
     ###########################################################
     ## for gradient of R.N wrt all betas
-    betaRN <- function (beta, object, region) {
-        ## assume region is a mask (no need for spacing)
+    betaRN <- function (beta, object, regionmask) {
+        ## regionmask is a mask (no need for spacing)
         ## assume single session
         ## n, cellarea, sessnum global
         object$fit$par <- beta
-        D <- predictD(object, region, session)
-        n + sumDpdot (object, sessnum, region, D, cellarea,
+        D <- predictD(object, regionmask, group, session)
+        n + sumDpdot (object, sessnum, regionmask, D, cellarea,
                   constant = FALSE, oneminus = TRUE)[1]
     }
     ###########################################################
@@ -95,11 +48,8 @@ region.N <- function (object, region = NULL, spacing = NULL, session = NULL,
     if (!all(session %in% session(object$capthist)))
         stop ("session incompatible with object ")
 
-    if (!is.null(group))
-        stop ("not yet working for groups")
-
-    if (!all(group %in% interaction (object$groups)))
-        stop ("unrecognised groups")
+    if (is.null(group))
+        group <- 1
 
     if (is.null(session))
         session <- session(object$capthist)
@@ -134,7 +84,13 @@ region.N <- function (object, region = NULL, spacing = NULL, session = NULL,
             mask <- object$mask
         ########################################################
         ## if necessary, convert vector region to raster
-        if (!inherits(region, 'mask')) {
+        if (inherits(region, 'mask')) {
+            if (ms(region))
+                 regionmask <- region[[session]]
+            else
+                regionmask <- region
+        }
+        else {
             if (is.null(spacing)) {
                 ## use mask spacing by default
                 spacing <- spacing(mask)
@@ -148,20 +104,16 @@ region.N <- function (object, region = NULL, spacing = NULL, session = NULL,
             else {
                 bbox <- apply(region, 2, range)
             }
-            region <- make.mask(bbox, poly = region, buffer = 0,
+            regionmask <- make.mask(bbox, poly = region, buffer = 0,
                 spacing = spacing, type = 'polygon',
                 check.poly = FALSE)
         }
+
         #######################################################
 
-        ## inserted to fix bug
-        ## 2011-09-26
-        if (ms(region))
-            region <- region[[session]]
-
         ## region now inherits from mask, so has area attribute
-        cellarea <- attr(region, 'area')
-        regionarea <- nrow(region) * cellarea
+        cellarea <- attr(regionmask, 'area')
+        regionarea <- nrow(regionmask) * cellarea
         if (ms(object))
             n <- nrow(object$capthist[[session]])
         else
@@ -171,14 +123,14 @@ region.N <- function (object, region = NULL, spacing = NULL, session = NULL,
         #######################################################
         ## for conditional likelihood fit,
         if (object$CL) {
-            temp <- derived(object) ## inefficient as repeats for each sess
+            temp <- derived(object, se.D = se.N) ## inefficient as repeats for each sess
             if (!is.data.frame(temp))
                 temp <- temp[[session]]
             D <- temp['D', 'estimate']
             seD <- temp['D', 'SE.estimate']
-            N <- D * regionarea
-            if (!se.N) return (N)    ## and stop here
-            seN <- seD * regionarea
+            EN <- D * regionarea
+            if (!se.N) return (EN)    ## and stop here
+            seEN <- seD * regionarea
         }
 
         #######################################################
@@ -187,60 +139,85 @@ region.N <- function (object, region = NULL, spacing = NULL, session = NULL,
             if (is.null(object$model$D) | is.null(object$link$D))
                 stop ("model or link function not found in object")
 
-            if (object$model$D == ~1) {
+            if ((object$model$D == ~1) & !userD(object)) {
                 predicted <- predict(object)
                 if (!is.data.frame(predicted))
                     predicted <- predicted[[1]]
                 D <- predicted['D','estimate']
-                N <- D * regionarea
-                seN <- predicted['D','SE.estimate'] * regionarea
+                seD <- predicted['D', 'SE.estimate']
+                EN <- D * regionarea
+                if (!se.N) return (EN)    ## and stop here
+                seEN <- seD * regionarea
             }
             else {
-                D <- predictD (object, region, session)
-                N <- sum(D) * cellarea
-                if (!se.N) return (N)    ## and stop here
+                D <- predictD (object, regionmask, group, session)
+                EN <- sum(D) * cellarea
+                if (!se.N) return (EN)    ## and stop here
                 indx <- object$parindx$D
-                dNdphi <- gradient (object$fit$par[indx],
-                    betaN, object = object, region = region, session =
-                    session, group = group)
+## simple gradient failed in test 2011-10-20
+#               dENdphi <- gradient (object$fit$par[indx],
+#                    betaEN, object = object, region = region, session =
+#                    session, group = group)
+                require (nlme)
+                dENdphi <- fdHess (object$fit$par[indx],
+                    betaEN, object = object, region = regionmask, group = group,
+                    session = session)$gradient
                 beta.vcv <- object$beta.vcv[indx,indx]
-                seN <- (dNdphi %*% beta.vcv %*% dNdphi)^0.5
+                seEN <- (dENdphi %*% beta.vcv %*% dENdphi)^0.5
             }
         }
 
         #######################################################################
         ## realised N
         ## only makes sense for individual detectors (not unmarked or presence)
+        ## assume if we have got this far that SE is required
         ## amended 2011-09-26
         if (ms(object))
             det <- detector(traps(object$capthist)[[session]])
         else
             det <- detector(traps(object$capthist))
         if (det %in% .localstuff$individualdetectors) {
-            notdetected <- sumDpdot (object, sessnum, region, D,
-                cellarea, constant = FALSE, oneminus = TRUE)[1]
-            dNdbeta <- gradient (object$fit$par, betaRN, object =
-                object, region = region)
-            RN <- n + notdetected
-            pdotvar <- dNdbeta %*% object$beta.vcv %*% dNdbeta
-            seRN <- (notdetected + pdotvar)^0.5
-            En <- sumDpdot (object, sessnum, mask, D, attr(mask,'area'),
-                 constant = FALSE, oneminus = FALSE)[1]
+            RN.method <- tolower(RN.method)
+            if (RN.method == 'mspe') {
+                notdetected <- sumDpdot (object, sessnum, regionmask, D,
+                    cellarea, constant = FALSE, oneminus = TRUE)[1]
+                RN <- n + notdetected
+                ## evaluate gradient of RN wrt betas at MLE
+##                dNdbeta <- gradient (object$fit$par, betaRN, object =
+##                    object, region = region)
+                require (nlme)
+                dNdbeta <- fdHess (object$fit$par, betaRN, object = object,
+                    region = regionmask)$gradient
+                ## compute variance from gradient & vcv
+                pdotvar <- dNdbeta %*% object$beta.vcv %*% dNdbeta
+                seRN <- (notdetected + pdotvar)^0.5
+            }
+            ## RN.method = 'poisson'
+            else {
+                RN <- EN
+                seRN <- (seEN^2 - EN)^0.5
+            }
         }
-        else { RN <- NA; seRN <- NA; En <- NA }
+        else { RN <- NA; seRN <- NA }
+
+# suppress 2011-11-10
+#            ## additional flourish - compute expected n
+#            En <- sumDpdot (object, sessnum, regionmask, D, attr(regionmask,'area'),
+#                 constant = FALSE, oneminus = FALSE)[1]
+#        else { RN <- NA; seRN <- NA; En <- NA }
         #######################################################################
 
         temp <- data.frame(
             row.names = c('E.N','R.N'),
-            estimate = c(N,RN),
-            SE.estimate = c(seN,seRN))
+            estimate = c(EN,RN),
+            SE.estimate = c(seEN,seRN))
         ## lower bound added 2011-07-15
         if (nlowerbound)
             temp <- add.cl (temp, alpha, loginterval, c(0, n))
         else
             temp <- add.cl (temp, alpha, loginterval, c(0, 0))
         temp$n <- rep(n, nrow(temp))
-        temp$E.n <- rep(round(En,2), nrow(temp))
+ #       temp$E.n <- rep(round(En,2), nrow(temp))
         if (keep.region)
             attr(temp, 'region') <- region
         temp
@@ -273,19 +250,15 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
 
     if (ms(mask))
         mask <- mask[[sessnum]]
-
     beta <- object$fit$par
 
     traps   <- attr(capthists, 'traps')  ## need session-specific traps
-    ## 2011-09-26 check added
     if (!(detector(traps) %in% .localstuff$individualdetectors))
         stop ("require individual detector type for sumDpdot")
     dettype <- detectorcode(traps)
     n       <- max(nrow(capthists), 1)
     s       <- ncol(capthists)
-
     noccasions <- s
-
     nmix    <- object$details$nmix
     nmix    <- ifelse (is.null(nmix), 1, nmix)
 
@@ -359,11 +332,14 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
         ## add density as third column of mask
         if (!(length(D) %in% c(1,nrow(mask))))
             stop ("D does not match mask in sumDpdot")
-        if (length(D) == 1)
-            D <- rep(D[1], nrow(mask))
-        mask <- cbind (mask, D)
 
-        useD <- TRUE
+        if (length(D) == 1) {
+            useD <- FALSE
+        }
+        else {
+            mask <- cbind (mask, D)
+            useD <- TRUE
+        }
         temp <- .C("integralprw1", PACKAGE = 'secr',
             as.integer(dettype),
             as.integer(param),
@@ -387,14 +363,20 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
             a=double(n),
             resultcode=integer(1)
        )
-       if (oneminus) {
-           temp$a <- sum(D) * cellarea - temp$a
-       }
        if (temp$resultcode == 3)
            stop ("groups not implemented in external function 'integralprw1'")
        if (temp$resultcode != 0)
            stop ("error in external function 'integralprw1'")
-       return(temp$a)
+       ## constant density case, D not passed to integralprw1
+       if (length(D) == 1) {
+           temp$a <- temp$a * D
+       }
+       if (oneminus) {
+           sumD <- ifelse (length(D) == 1, D * nrow(mask), sum(D))
+           return(sumD * cellarea - temp$a)
+       }
+       else
+           return(temp$a)
     }
 }
 ############################################################################################
@@ -459,7 +441,7 @@ expected.n <- function (object, session = NULL, group = NULL, bycluster = FALSE,
         #######################################################
         ## for conditional likelihood fit,
         if (object$CL) {
-            temp <- derived(object) ## inefficient as repeats for each sess
+            temp <- derived(object, se.D = FALSE) ## inefficient as repeats for each sess
             if (!is.data.frame(temp))
                 temp <- temp[[session]]
             D <- temp['D', 'estimate']
@@ -478,7 +460,7 @@ expected.n <- function (object, session = NULL, group = NULL, bycluster = FALSE,
                 D <- predicted['D','estimate']
             }
             else {
-                D <- predictD (object, mask, session)
+                D <- predictD (object, mask, group, session)
             }
         }
         #################################################################
@@ -505,10 +487,6 @@ expected.n <- function (object, session = NULL, group = NULL, bycluster = FALSE,
                         constant = FALSE, oneminus = FALSE)[1]
                 }
                 else {
-## replaced 2011-08-18
-##                    traps(object$capthist) <- subset(trps, subset =
-##                        as.numeric(clusterID(trps)) == i)
-
                     temptrap <- subset(trps, subset = as.numeric(clusterID(trps)) == i)
                     if (ms(object))
                         traps(object$capthist[[sessnum]]) <- temptrap
